@@ -3,9 +3,9 @@
 #include <stdlib.h>
 #include <skalibs/alloc.h>
 
-int alloc_realloc (void **x, size_t n)
+int alloc_realloc (char **x, size_t n)
 {
-  void *y = n ? realloc(*x, n) : (free(*x), alloc(0)) ;
+  char *y = n ? (char *)realloc(*x, n) : (free(*x), (char *)alloc(0)) ;
   if (!y) return 0 ;
   *x = y ;
   return 1 ;
