@@ -5,5 +5,5 @@
 
 size_t allwrite (int fd, char const *buf, size_t len)
 {
-  return allreadwrite((iofunc_t_ref)&fd_write, fd, (char *)buf, len) ;
+  return allreadwrite((io_func_ref)&fd_write, fd, (char *)buf, len) ;
 }
