@@ -16,6 +16,7 @@ int selfpipe_fd = -1 ;
 #else
 
 #include <unistd.h>
+#include <errno.h>
 
 #include <skalibs/allreadwrite.h>
 
@@ -23,8 +24,10 @@ int selfpipe[2] = { -1, -1 } ;
 
 void selfpipe_tophalf (int s)
 {
+  int e = errno ;
   unsigned char c = (unsigned char)s ;
   write(selfpipe[1], (char *)&c, 1) ;
+  errno = e ;
 }
 
 #endif
