@@ -6,13 +6,13 @@
 unsigned int siovec_trunc (struct iovec *v, unsigned int n, size_t len)
 {
   size_t w = siovec_len(v, n) ;
-  unsigned int i = n ;
   if (w < len) return n ;
   len = w - len ;
-  while (len && i--)
+  while (n && len)
   {
-    w = len > v[i].iov_len ? v[i].iov_len : len ;
-    v[i].iov_len -= w ; len -= w ;
+    w = len > v[n-1].iov_len ? v[n-1].iov_len : len ;
+    v[n-1].iov_len -= w ; len -= w ;
+    if (!v[n-1].iov_len) n-- ;
   }
-  return i ;
+  return n ;
 }
