@@ -1,9 +1,11 @@
 /* ISC license. */
 
 #include <skalibs/nonposix.h>
+
 #include <sys/socket.h>
 #include <string.h>
 #include <netinet/in.h>
+
 #include <skalibs/uint16.h>
 #include <skalibs/socket.h>
 
@@ -12,8 +14,7 @@ int socket_bind4 (int s, char const *ip, uint16_t port)
   struct sockaddr_in sa ;
   memset(&sa, 0, sizeof sa) ;
   sa.sin_family = AF_INET ;
-  uint16_big_endian((char *)&port, 1) ;
-  sa.sin_port = port ;
+  sa.sin_port = uint16_big(port) ;
   memcpy(&sa.sin_addr.s_addr, ip, 4) ;
   return bind(s, (struct sockaddr *)&sa, sizeof sa) ;
 }
