@@ -4,4 +4,4 @@
 
 #include <skalibs/tai.h>
 
-tain_t STAMP = TAIN_EPOCH ;
+tain STAMP = TAIN_EPOCH ;
