@@ -4,4 +4,4 @@
 
 #include <skalibs/sgetopt.h>
 
-subgetopt_t subgetopt_here = SUBGETOPT_ZERO ;
+subgetopt subgetopt_here = SUBGETOPT_ZERO ;
