@@ -2,7 +2,7 @@
 
 #include <skalibs/tai.h>
 
-int tai_sub (tai_t *t, tai_t const *u, tai_t const *v)
+int tai_sub (tai *t, tai const *u, tai const *v)
 {
   t->x = u->x - v->x ;
   return 1 ;
