@@ -3,7 +3,7 @@
 #include <errno.h>
 #include <skalibs/tai.h>
 
-int tain_from_millisecs (tain_t *a, int millisecs)
+int tain_from_millisecs (tain *a, int millisecs)
 {
   if (millisecs < 0) return (errno = EINVAL, 0) ;
   a->sec.x = millisecs / 1000 ;
