@@ -2,7 +2,7 @@
 
 #include <skalibs/tai.h>
 
-int tain_from_sysclock (tain_t *a, tain_t const *u)
+int tain_from_sysclock (tain *a, tain const *u)
 {
   if (!tai_from_sysclock(&a->sec, u->sec.x)) return 0 ;
   a->nano = u->nano ;
