@@ -2,7 +2,7 @@
 
 #include <skalibs/tai.h>
 
-int tain_less (tain_t const *t, tain_t const *u)
+int tain_less (tain const *t, tain const *u)
 {
   if (tai_sec(&t->sec) < tai_sec(&u->sec)) return 1 ;
   if (tai_sec(&t->sec) > tai_sec(&u->sec)) return 0 ;
